@@ -123,8 +123,10 @@ opal.assign.table <- function(opal, symbol, value, variables=NULL, missings=FALS
     if (async) {
       query["async"] <- "true"
     }
-    ignore <- .getRSessionId(opal)
-    res <- opal.put(opal, "r", "session", opal$rid, "symbol", symbol, body=body, contentType=contentType, query=query)
+    res <- opal.put(opal, opal$context, "session", opal.session(opal), "symbol", symbol, body=body, contentType=contentType, query=query)
+    if (async) {
+      res
+    }
   }
 }
 
@@ -153,7 +155,7 @@ opal.assign.table <- function(opal, symbol, value, variables=NULL, missings=FALS
 #' }
 #' @export
 opal.assign.table.tibble <- function(opal, symbol, value, variables=NULL, missings=FALSE, identifiers=NULL, id.name='id', with.factors=FALSE, updated.name=NULL, async=FALSE) {
-  ignore <- .getRSessionId(opal)
+  ignore <- opal.session(opal)
   if (!is.na(opal$version) && opal.version_compare(opal,"2.8")<0) {
     warning("Export to tibble not available for opal ", opal$version, " (2.8.0 or higher is required)")
   } else if (with.factors && !is.na(opal$version) && opal.version_compare(opal,"2.14")<0) {
@@ -195,8 +197,10 @@ opal.assign.script <- function(opal, symbol, value, async=FALSE) {
     if (async) {
       query["async"] <- "true"
     }
-    ignore <- .getRSessionId(opal)
-    res <- opal.put(opal, "r", "session", opal$rid, "symbol", symbol, body=body, contentType=contentType, query=query)
+    res <- opal.put(opal, opal$context, "session", opal.session(opal), "symbol", symbol, body=body, contentType=contentType, query=query)
+    if (async) {
+      res
+    }
   }
 }
 
@@ -233,8 +237,10 @@ opal.assign.data <- function(opal, symbol, value, async=FALSE) {
     if (async) {
       query["async"] <- "true"
     }
-    ignore <- .getRSessionId(opal)
-    res <- opal.post(opal, "r", "session", opal$rid, "symbol", symbol, body=body, contentType=contentType, query=query)
+    res <- opal.post(opal, opal$context, "session", opal.session(opal), "symbol", symbol, body=body, contentType=contentType, query=query)
+    if (async) {
+      res
+    }
   }
 }
 
@@ -267,7 +273,9 @@ opal.assign.resource <- function(opal, symbol, value, async=FALSE) {
     if (async) {
       query["async"] <- "true"
     }
-    ignore <- .getRSessionId(opal)
-    res <- opal.put(opal, "r", "session", opal$rid, "symbol", symbol, "resource", value, query=query)
+    res <- opal.put(opal, opal$context, "session", opal.session(opal), "symbol", symbol, "resource", value, query=query)
+    if (async) {
+      res
+    }
   }
 }
